// Persistence of Vision Ray Tracer Scene Description File
// File: bonaventure.pov
// Vers: 1
// Desc: An interstellar heavy cruiser
// Date: 2015-08-13
// Auth: Felix Plesoianu <felixp7@yahoo.com>

#include "colors.inc"
#include "textures.inc"
#include "metals.inc"

// Space
sphere {
	<0, 0, 0>, 10000 hollow
	// You'll want to vary scale with render resolution.
	// 10000 (1:1 with the sphere radius) is good for a small render.
	texture { Starfield scale 2500 }
}

camera {
	location <0, 20, 0>
	look_at <-20, 0, 100>
	angle 48
	//angle 24
}

light_source { <0, 0, -9999> color White rotate <-30, -15, 0> }

sphere {
	<0, 0, 6000>, 3000
	pigment { Brown_Agate scale 3000 }
	rotate y * 5
}


#declare Hull_Shape = sphere { <0, 0, 0>, 0.5 scale <55, 21, 377> }
#declare Unit_Box = box { <-0.5, -0.5, -0.5>, <0.5, 0.5, 0.5> }
#declare Unit_Sphere = sphere { <0, 0, 0>, 0.5 }

#declare Gun_Turret =
union {
	difference {
		sphere { <0, 0, 0>, 0.5 scale <8, 3, 8> }
		box { <-5, -0.125, -5>, <5, 0.125, 5> texture { T_Chrome_1A } }
		box { <-1.5, 0, 0>, <1.5, 2, 5> texture { T_Chrome_1A } }
	}
	cylinder { <0, 0, 0>, <0, 0, 5>, 0.4 translate <0, 1, 0> }
	cylinder { <0, 0, 0>, <0, 0, 5>, 0.4 translate <1, 1, 0> }
	cylinder { <0, 0, 0>, <0, 0, 5>, 0.4 translate <-1, 1, 0> }
	texture { T_Chrome_2A }
}

#declare Neon = media {
	emission 1
	density {
		cylindrical
		color_map {
			[0.5 rgb <0, 0, 0.5>]
			[1.0 rgb <0, 0.8, 0.8>]
		}
	}
	//scale 0.1
}

union {
	difference {
		object { Hull_Shape }
		object { Unit_Box scale <89, 1, 55> translate z * 124 }
		object { Unit_Box scale <89, 1, 55> translate <0, 3, 124> }
		object { Unit_Box scale <89, 1, 55> translate <0, -3, 124> }

		object { Unit_Box scale <89, 1, 55> translate <0, 6, 34> }
		object { Unit_Box scale <89, 1, 55> translate <0, -6, 34> }
		object { Unit_Box scale <89, 1, 55> translate <0, 6, -34> }
		object { Unit_Box scale <89, 1, 55> translate <0, -6, -34> }
		
		object {
			Unit_Box
			scale <89, 1, 55>
			translate <0, -3, 188.5>
			texture { T_Chrome_1A }
		}
		object {
			Unit_Sphere
			scale <5, 3, 21>
			translate z * -188.5
			texture { T_Chrome_1A }
		}
	}
	
	// The windows
	difference {
		object {
			Hull_Shape
			scale 0.99
			texture {
				Yellow_Glass
				normal { cells }
				finish { reflection 1 }
			}
		}
		
		object { Unit_Box scale <89, 1, 55> translate <0, -3, 188.5> }
		object { Unit_Sphere scale <5, 3, 21> translate z * -188.5 }
	}
	
	// The hangars
	intersection {
		object { Hull_Shape }
		object { Unit_Box scale <89, 8, 55> }
		scale x * 1.05
	}
	intersection {
		object { Hull_Shape }
		object { Unit_Box scale <89, 8, 55> translate z * 63 }
		scale x * 1.05
	}
	intersection {
		object { Hull_Shape }
		object { Unit_Box scale <89, 8, 55> translate z * -63 }
		scale x * 1.05
	}
	
	// The gills.
	intersection {
		object { Hull_Shape }
		object { Unit_Box scale <89, 2, 2> translate <0, 6, 89> }
		scale x * 1.05
		texture { T_Chrome_1A }
	}
	intersection {
		object { Hull_Shape }
		object { Unit_Box scale <89, 2, 2> translate <0, 6, 85> }
		scale x * 1.05
		texture { T_Chrome_1A }
	}
	intersection {
		object { Hull_Shape }
		object { Unit_Box scale <89, 2, 2> translate <0, 6, 81> }
		scale x * 1.05
		texture { T_Chrome_1A }
	}
	
	// Tail end detail.
	intersection {
		object { Hull_Shape }
		object { Unit_Box scale <89, 1, 5> translate <0, 4.5, -139> }
		scale x * 1.05
		texture { T_Chrome_1A }
	}
	intersection {
		object { Hull_Shape }
		object { Unit_Box scale <89, 1, 5> translate <0, -4.5, -139> }
		scale x * 1.05
		texture { T_Chrome_1A }
	}
	
	// Top fin
	cone {
		<0, 10, 0>, 21, <0, 21, 0>, 8
		scale x * 0.1
	}
	
	// Ventral fins
	cone {
		<0, 0, 89>, 21, <-34, 0, 89>, 8
		scale y * 0.1
		rotate z * 30
	}
	cone {
		<0, 0, 89>, 21, <34, 0, 89>, 8
		scale y * 0.1
		rotate z * -30
	}
	cone {
		<0, 0, -89>, 13, <-27.5, 0, -89>, 5
		scale y * 0.1
		rotate z * 30
	}
	cone {
		<0, 0, -89>, 13, <27.5, 0, -89>, 5
		scale y * 0.1
		rotate z * -30
	}
	
	// Tail fins
	cone {
		<0, 0, -175>, 8, <0, 17, -188.5>, 2
		scale x * 0.1
	}
	cone {
		<0, 0, -175>, 8, <0, -8, -180>, 2
		scale x * 0.1
	}
	
	object { Gun_Turret translate <0, 6, 161> }
	object { Gun_Turret translate <0, 9.5, 89> }
	object { Gun_Turret rotate y * 180 translate <0, 9.5, -89> }
	object { Gun_Turret rotate z * 180 translate <0, -9.5, 89> }
	object { Gun_Turret rotate <0, 180, 180> translate <0, -9.5, -89> }
	
	cone {
		<0, 0, -187>, 0.5, <0, 0, -277.5>, 0 scale <5, 3, 1>
		hollow interior { media { Neon rotate x * 90 } }
		texture { Glass2 }
	}
	
	texture { T_Chrome_2A normal { cells scale 10 }	}
	//no_shadow
	rotate z * -24
	rotate y * -156
	//rotate y * 15
	translate z * 300
}
