// Persistence of Vision Ray Tracer Scene Description File
// File: space-window.pov
// Vers: 1
// Desc: Looking out into space to a mysterious ship...
// Date: 2015-08-09
// Auth: Felix Plesoianu <felixp7@yahoo.com>

#include "colors.inc"
#include "textures.inc"
#include "metals.inc"

#declare White_PLastic =
texture {
	pigment { color White }
	finish { specular 0.8 }
}


// Space
sphere {
	<0, 0, 0>, 10000 hollow
	// You'll want to vary scale with render resolution.
	// 10000 (1:1 with the sphere radius) is good for a small render.
	texture { Starfield scale 2500 }
}

camera {
	location <0.15, 0, 0.15>
	look_at <0.05, 0, 1>
	right x
	angle 72
}

light_group {
	light_source { <0, 0.90, 0> color rgb <1, 1, 0.8> }
	difference {
		sphere { <0, 0, 0>, 1.05 }
		sphere { <0, 0, 0>, 0.95 }
		cylinder { <0, 0, 0>, <0, 0, 1.1>, 0.15 }
		#declare Window_A = 0;
		#while (Window_A < 360)
			cylinder {
				<0, 0, 0>, <0, 0, 1.1>, 0.15
				rotate y * 20
				rotate z * Window_A
			}
			#declare Window_A = Window_A + 60;
		#end
		texture { White_PLastic }
	}
	/*difference {
		sphere { <0, 0, 0>, 1.025 }
		sphere { <0, 0, 0>, 0.975 }
		material { M_Glass }
	}*/
}

light_group {
	light_source { <0, 0, -9999> color White rotate <30, -30, 0> }
	sphere {
		<0, 0, 6000>, 3000
		pigment { Blue_Agate scale 3000 }
		rotate y * -30
	}
	union {
		difference {
			box {
				<-300, -25, -50>, <300, 25, 50>
				texture {
					T_Chrome_2A
					normal { cells scale 10 }
				}
			}
			
			// The big trenches
			box {
				<-2, -26, -51>, <2, 26, 51>
				texture { T_Chrome_2A }
				translate x * -100
			}
			box {
				<-2, -26, -51>, <2, 26, 51>
				texture { T_Chrome_2A }
				translate x * 100
			}
			
			box {
				<-2, 0, 0>, <2, 26, -51>
				texture { T_Chrome_2A }
				translate x * -200
			}
		}
		
		// The internal lights
		box {
			<-298, -23, -48>, <298, 23, 48>
			texture {
				Yellow_Glass
				normal { cells scale 4 }
				finish { reflection 1 }
			}
		}
		
		box {
			<200, -27, -25>, <300, 27, 25>
			texture {
				T_Chrome_2A
				normal { cells scale 10 }
			}
		}
		box {
			<200, -12.5, -52>, <300, 12.5, 52>
			texture {
				T_Chrome_2A
				normal { cells scale 10 }
			}
		}
		
		no_shadow
		rotate <-30, -45, 0>
		translate z * 600
	}
}
